@@ -29,7 +29,7 @@ static void antiidle(void)
 
 /*
  * Introduce a random delay, to mitigate guessing existing user names by
- * mesuring delay. It's especially true when LDAP is used.
+ * measuring delay. It's especially true when LDAP is used.
  * No need to call usleep2() because we are root at this point.
  */
 
@@ -247,6 +247,12 @@ void parser(void)
             }
 #endif
         }
+        if (deferred_quit != 0) {
+            addreply(221, MSG_GOODBYE,
+                     (unsigned long long) ((uploaded + 1023ULL) / 1024ULL),
+                     (unsigned long long) ((downloaded + 1023ULL) / 1024ULL));
+            return;
+        }
         doreply();
         alarm(idletime * 2);
         switch (sfgets()) {
@@ -257,7 +263,7 @@ void parser(void)
             die(421, LOG_INFO, MSG_TIMEOUT_PARSER);
 #endif
         case -2:
-            return;
+            die(425, LOG_INFO, MSG_LOGOUT);
         }
 #ifdef DEBUG
         if (debug != 0) {
