@@ -269,7 +269,6 @@ static int pw_pgsql_connect(PGconn ** const id_sql_server)
     char *conninfo = NULL;
     size_t sizeof_conninfo;
     char *escaped_server = NULL;
-    char *escaped_port = NULL;
     char *escaped_db = NULL;
     char *escaped_user = NULL;
     char *escaped_pw = NULL;
@@ -278,7 +277,6 @@ static int pw_pgsql_connect(PGconn ** const id_sql_server)
     *id_sql_server = NULL;
 
     if ((escaped_server = pw_pgsql_escape_conninfo(server)) == NULL ||
-        (escaped_port = pw_pgsql_escape_conninfo(port)) == NULL ||
         (escaped_db = pw_pgsql_escape_conninfo(db)) == NULL ||
         (escaped_user = pw_pgsql_escape_conninfo(user)) == NULL ||
         (escaped_pw = pw_pgsql_escape_conninfo(pw)) == NULL) {
@@ -296,7 +294,7 @@ static int pw_pgsql_connect(PGconn ** const id_sql_server)
     }
     if (SNCHECK(snprintf(conninfo, sizeof_conninfo,
                          PGSQL_CONNECT_FMTSTRING,
-                         escaped_server, escaped_port, escaped_db,
+                         escaped_server, port, escaped_db,
                          escaped_user, escaped_pw), sizeof_conninfo)) {
         goto bye;
     }
@@ -314,7 +312,6 @@ static int pw_pgsql_connect(PGconn ** const id_sql_server)
     bye:
     free(conninfo);
     free(escaped_server);
-    free(escaped_port);
     free(escaped_db);
     free(escaped_user);
     free(escaped_pw);
@@ -547,7 +544,7 @@ void pw_pgsql_check(AuthResult * const result,
 
     auth_ok:
     /*
-     * do *NOT* accept root uid/gid - if the database is compromized, the FTP
+     * do *NOT* accept root uid/gid - if the database is compromised, the FTP
      * server could also be rooted.
      */
     result->uid = (uid_t) strtoul(uid, NULL, 10);
