@@ -61,6 +61,11 @@ static int ssl_servername_cb(SSL *cnx, int *al, void *arg)
     if (chrooted != 0 || loggedin != 0) {
         return SSL_TLSEXT_ERR_NOACK;
     }
+    if (client_sni_name == NULL) {
+        if ((client_sni_name = strdup(sni_name)) == NULL) {
+            die_mem();
+        }
+    }
     if (use_extcert == 0) {
         return SSL_TLSEXT_ERR_OK;
     }
@@ -95,9 +100,6 @@ static int ssl_servername_cb(SSL *cnx, int *al, void *arg)
             die(400, LOG_ERR, "SSL error");
         }
     }
-    if ((client_sni_name = strdup(sni_name)) == NULL) {
-        die_mem();
-    }
     if (tls_cnx != NULL) {
         const long ctx_options = SSL_CTX_get_options(tls_ctx);
         SSL_set_SSL_CTX(tls_cnx, tls_ctx);
